summaryrefslogtreecommitdiffstats
path: root/kcoloredit/kcoloreditview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcoloredit/kcoloreditview.h')
-rw-r--r--kcoloredit/kcoloreditview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kcoloredit/kcoloreditview.h b/kcoloredit/kcoloreditview.h
index 1ede4427..74b16d43 100644
--- a/kcoloredit/kcoloreditview.h
+++ b/kcoloredit/kcoloreditview.h
@@ -47,11 +47,11 @@ class KColorEditView : public TQSplitter {
public:
/** Constructor for the main view */
- KColorEditView(TQWidget *tqparent = 0, const char *name = 0);
+ KColorEditView(TQWidget *parent = 0, const char *name = 0);
/** Destructor for the main view */
~KColorEditView();
/** returns a pointer to the document connected to the view instance. Mind that this method requires a KColorEditApp instance as a tqparent
* widget to get to the window document pointer by calling the KColorEditApp::getDocument() method.
*
* @see KColorEditApp#getDocument
@@ -47,11 +47,11 @@ class KColorEditView : public TQSplitter {
/** Destructor for the main view */
~KColorEditView();
- /** returns a pointer to the document connected to the view instance. Mind that this method requires a KColorEditApp instance as a tqparent
+ /** returns a pointer to the document connected to the view instance. Mind that this method requires a KColorEditApp instance as a parent
* widget to get to the window document pointer by calling the KColorEditApp::getDocument() method.
*